Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBastien Montagne <b.mont29@gmail.com>2020-03-04 12:38:30 +0300
committerBastien Montagne <b.mont29@gmail.com>2020-03-04 13:43:30 +0300
commit76d8e8693fab13d300130dc3a9bd75f6f637991d (patch)
treee60aa5b48717e94e335dcb93490363e3da42987b /source/blender/makesrna/intern/rna_ID.c
parente4eede83187d6e4f784491532a0887d4f8c9ba31 (diff)
Cleanup: Rename 'make local' functions to new scheme.
Also removed some only used locally from the header, `BKE_lib_id.h` is already way too big, no need to overload it with unused things.
Diffstat (limited to 'source/blender/makesrna/intern/rna_ID.c')
-rw-r--r--source/blender/makesrna/intern/rna_ID.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/source/blender/makesrna/intern/rna_ID.c b/source/blender/makesrna/intern/rna_ID.c
index 12fa8150d5f..b1c20bcd8f2 100644
--- a/source/blender/makesrna/intern/rna_ID.c
+++ b/source/blender/makesrna/intern/rna_ID.c
@@ -582,12 +582,12 @@ static void rna_ID_user_remap(ID *id, Main *bmain, ID *new_id)
static struct ID *rna_ID_make_local(struct ID *self, Main *bmain, bool clear_proxy)
{
/* Special case, as we can't rely on id_make_local(); it clears proxies. */
if (!clear_proxy && GS(self->name) == ID_OB) {
BKE_object_make_local_ex(bmain, (Object *)self, false, clear_proxy);
}
else {
- id_make_local(bmain, self, false, false);
+ BKE_lib_id_make_local(bmain, self, false, false);
}
ID *ret_id = self->newid ? self->newid : self;
@@ -582,12 +582,12 @@ static void rna_ID_user_remap(ID *id, Main *bmain, ID *new_id)
static struct ID *rna_ID_make_local(struct ID *self, Main *bmain, bool clear_proxy)
{
- /* Special case, as we can't rely on id_make_local(); it clears proxies. */
+ /* Special case, as we can't rely on BKE_lib_id_make_local(); it clears proxies. */
if (!clear_proxy && GS(self->name) == ID_OB) {
BKE_object_make_local_ex(bmain, (Object *)self, false, clear_proxy);